==> qtjambi-uic-6.3.5-sources.jar: io/qt/uic/ui4/DomPalette.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomPalette</p>
 */
public class DomPalette extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomPalette(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomPalette instance);
    
    @io.qt.QtUninvokable
    public final void clearElementActive(){
        clearElementActive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementActive_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementDisabled(){
        clearElementDisabled_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementDisabled_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementInactive(){
        clearElementInactive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementInactive_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomColorGroup elementActive(){
        return elementActive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup elementActive_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomColorGroup elementDisabled(){
        return elementDisabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup elementDisabled_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomColorGroup elementInactive(){
        return elementInactive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup elementInactive_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementActive(){
        return hasElementActive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementActive_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementDisabled(){
        return hasElementDisabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementDisabled_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementInactive(){
        return hasElementInactive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementInactive_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setElementActive(io.qt.uic.ui4.DomColorGroup a){
        setElementActive_native_DomColorGroup_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementActive_native_DomColorGroup_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final void setElementDisabled(io.qt.uic.ui4.DomColorGroup a){
        setElementDisabled_native_DomColorGroup_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementDisabled_native_DomColorGroup_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final void setElementInactive(io.qt.uic.ui4.DomColorGroup a){
        setElementInactive_native_DomColorGroup_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @io.qt.QtUninvokable
    private native void setElementInactive_native_DomColorGroup_ptr(long __this__nativeId, long a);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomColorGroup takeElementActive(){
        return takeElementActive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup takeElementActive_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomColorGroup takeElementDisabled(){
        return takeElementDisabled_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup takeElementDisabled_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.uic.ui4.DomColorGroup takeElementInactive(){
        return takeElementInactive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup takeElementInactive_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomPalette(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-6.5.1-sources.jar: io/qt/uic/ui4/DomPalette.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class DomPalette</p>
 */
public class DomPalette extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomPalette(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomPalette instance);
    
    @QtUninvokable
    public final void clearElementActive(){
        clearElementActive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementActive_native(long __this__nativeId);
    
    @QtUninvokable
    public final void clearElementDisabled(){
        clearElementDisabled_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementDisabled_native(long __this__nativeId);
    
    @QtUninvokable
    public final void clearElementInactive(){
        clearElementInactive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementInactive_native(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup elementActive(){
        return elementActive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup elementActive_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup elementDisabled(){
        return elementDisabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup elementDisabled_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup elementInactive(){
        return elementInactive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup elementInactive_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasElementActive(){
        return hasElementActive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementActive_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasElementDisabled(){
        return hasElementDisabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementDisabled_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasElementInactive(){
        return hasElementInactive_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementInactive_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @QtUninvokable
    public final void setElementActive(io.qt.uic.ui4.@Nullable DomColorGroup a){
        setElementActive_native_DomColorGroup_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementActive_native_DomColorGroup_ptr(long __this__nativeId, long a);
    
    @QtUninvokable
    public final void setElementDisabled(io.qt.uic.ui4.@Nullable DomColorGroup a){
        setElementDisabled_native_DomColorGroup_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementDisabled_native_DomColorGroup_ptr(long __this__nativeId, long a);
    
    @QtUninvokable
    public final void setElementInactive(io.qt.uic.ui4.@Nullable DomColorGroup a){
        setElementInactive_native_DomColorGroup_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(a));
    }
    
    @QtUninvokable
    private native void setElementInactive_native_DomColorGroup_ptr(long __this__nativeId, long a);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup takeElementActive(){
        return takeElementActive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup takeElementActive_native(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup takeElementDisabled(){
        return takeElementDisabled_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup takeElementDisabled_native(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.uic.ui4.@Nullable DomColorGroup takeElementInactive(){
        return takeElementInactive_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.uic.ui4.DomColorGroup takeElementInactive_native(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected DomPalette(QPrivateConstructor p) { super(p); } 
    
}
